@@ -17,6 +17,7 @@ from pygments import highlight
 # from pygments.lexers import get_lexer_for_filename, TextLexer, ClassNotFound
 from pygments.lexers import TextLexer
 from pygments.formatters import HtmlFormatter
+from urllib import urlencode
 
 from django.http import QueryDict
 from django.utils.html import escape
@@ -296,6 +297,10 @@ class Frame(object):
         self.context_line = context_line
         self.pre_context = pre_context
         self.post_context = post_context
+        if isinstance(vars, (list, tuple)):
+            vars = dict(enumerate(vars))
+        if isinstance(data, (list, tuple)):
+            data = dict(enumerate(data))
         self.vars = vars or {}
         self.data = data or {}
 
@@ -917,9 +922,15 @@ class Http(Interface):
             # remove '?' prefix
             query_string = query_string[1:]
 
+        if isinstance(data, (list, tuple)):
+            data = dict(enumerate(data))
+
         self.url = '%s://%s%s' % (urlparts.scheme, urlparts.netloc, urlparts.path)
         self.method = method
         self.data = data
+        # if querystring was a dict, convert it to a string
+        if isinstance(query_string, dict):
+            query_string = urlencode(query_string.items())
         self.query_string = query_string
         if cookies:
             self.cookies = cookies
@@ -1120,21 +1131,25 @@ class User(Interface):
     """
     An interface which describes the authenticated User for a request.
 
-    All data is arbitrary and optional other than the ``id``
-    field which should be a string representing the user's unique identifier.
+    You should provide **at least** either an `id` (a unique identifier for
+    an authenticated user) or `ip_address` (their IP address).
+
+    All other data is.
 
     >>> {
     >>>     "id": "unique_id",
     >>>     "username": "my_user",
     >>>     "email": "foo@example.com"
+    >>>     "ip_address": "127.0.0.1"
     >>> }
     """
     attrs = ('id', 'email', 'username', 'data')
 
-    def __init__(self, id=None, email=None, username=None, **kwargs):
+    def __init__(self, id=None, email=None, username=None, ip_address=None, **kwargs):
         self.id = id
         self.email = email
         self.username = username
+        self.ip_address = ip_address
         self.data = kwargs
 
     def serialize(self):
@@ -1146,6 +1161,7 @@ class User(Interface):
             'id': self.id,
             'username': self.username,
             'email': self.email,
+            'ip_address': self.ip_address,
             'data': self.data,
         }
 
@@ -1158,6 +1174,7 @@ class User(Interface):
         return render_to_string('sentry/partial/interfaces/user.html', {
             'is_public': is_public,
             'event': event,
+            'user_ip_address': self.ip_address,
             'user_id': self.id,
             'user_username': self.username,
             'user_email': self.email,
