@@ -35,7 +35,8 @@ from raven.utils.encoding import to_string
 from sentry import app
 from sentry.constants import (
     STATUS_RESOLVED, STATUS_UNRESOLVED, MINUTE_NORMALIZATION,
-    MAX_EXTRA_VARIABLE_SIZE, LOG_LEVELS, DEFAULT_LOGGER_NAME)
+    MAX_EXTRA_VARIABLE_SIZE, LOG_LEVELS, DEFAULT_LOGGER_NAME,
+    MAX_CULPRIT_LENGTH)
 from sentry.processors.base import send_group_processors
 from sentry.signals import regression_signal
 from sentry.tasks.index import index_event
@@ -377,6 +378,7 @@ class GroupManager(BaseManager, ChartMixin):
     use_for_related_fields = True
 
     def normalize_event_data(self, data):
+        # TODO(dcramer): store http.env.REMOTE_ADDR as user.ip
         # First we pull out our top-level (non-data attr) kwargs
         if not data.get('level') or data['level'] not in LOG_LEVELS:
             data['level'] = logging.ERROR
@@ -479,7 +481,7 @@ class GroupManager(BaseManager, ChartMixin):
 
             # default the culprit to the url
             if not data['culprit']:
-                data['culprit'] = strip(http_data.get('url'))
+                data['culprit'] = trim(strip(http_data.get('url')), MAX_CULPRIT_LENGTH)
 
         return data
 
@@ -867,7 +869,8 @@ class RawQuerySet(object):
 
 
 class ProjectManager(BaseManager, ChartMixin):
-    def get_for_user(self, user=None, access=None, hidden=False, team=None):
+    def get_for_user(self, user=None, access=None, hidden=False, team=None,
+                     superuser=True):
         """
         Returns a SortedDict of all projects a user has some level of access to.
         """
@@ -885,7 +888,7 @@ class ProjectManager(BaseManager, ChartMixin):
         if team:
             base_qs = base_qs.filter(team=team)
 
-        if team and user.is_superuser:
+        if team and user.is_superuser and superuser:
             projects = set(base_qs)
         else:
             projects_qs = base_qs
@@ -907,7 +910,7 @@ class ProjectManager(BaseManager, ChartMixin):
 
         attach_foreignkey(projects, self.model.team)
 
-        return sorted(projects, key=lambda x: x.name)
+        return sorted(projects, key=lambda x: x.name.lower())
 
 
 class MetaManager(BaseManager):
@@ -1270,7 +1273,7 @@ class TeamManager(BaseManager):
             return results
 
         if settings.SENTRY_PUBLIC and access is None:
-            for team in self.order_by('name').iterator():
+            for team in sorted(self.iterator(), key=lambda x: x.name.lower()):
                 results[team.slug] = team
         else:
             all_teams = set()
@@ -1294,15 +1297,15 @@ class TeamManager(BaseManager):
                 for group in qs:
                     all_teams.add(group.team)
 
-            for team in sorted(all_teams, key=lambda x: x.name):
+            for team in sorted(all_teams, key=lambda x: x.name.lower()):
                 results[team.slug] = team
 
         if with_projects:
             # these kinds of queries make people sad :(
             new_results = SortedDict()
             for team in results.itervalues():
-                project_list = Project.objects.get_for_user(
-                    user, team=team)[:20]
+                project_list = list(Project.objects.get_for_user(
+                    user, team=team))
                 new_results[team.slug] = (team, project_list)
             results = new_results
 
