@@ -518,6 +518,22 @@ class EventBase(Model):
     def team(self):
         return self.project.team
 
+    @property
+    def ip_address(self):
+        http_data = self.data.get('sentry.interfaces.Http')
+        if http_data and 'env' in http_data:
+            value = http_data['env'].get('REMOTE_ADDR')
+            if value:
+                return value
+
+        user_data = self.data.get('sentry.interfaces.User')
+        if user_data:
+            value = user_data.get('ip_address')
+            if value:
+                return value
+
+        return None
+
     @property
     def user_ident(self):
         """
@@ -545,12 +561,9 @@ class EventBase(Model):
             if ident:
                 return 'username:%s' % (ident,)
 
-        http_data = self.data.get('sentry.interfaces.Http')
-        if http_data:
-            if 'env' in http_data:
-                ident = http_data['env'].get('REMOTE_ADDR')
-                if ident:
-                    return 'ip:%s' % (ident,)
+        ident = self.ip_address
+        if ident:
+            return 'ip:%s' % (ident,)
 
         return None
 
